==> glfw-doc-3.3.9-1-aarch64.pkg.tar.xz: usr/share/doc/glfw/html/search/all_8.js <==
var searchData=
[
  ['egl_20support_0',['(Experimental) EGL support',['../news.html#news_30_egl',1,'']]],
  ['empty_20events_20on_20x11_20no_20longer_20roundtrip_20to_20server_1',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['enter_20leave_20callback_2',['Cursor enter/leave callback',['../news.html#news_30_enterleave',1,'']]],
  ['enter_20leave_20events_3',['Cursor enter/leave events',['../input_guide.html#cursor_enter',1,'']]],
  ['enumeration_4',['Video mode enumeration',['../moving_guide.html#moving_video_modes',1,'']]],
  ['error_20callback_5',['error callback',['../news.html#news_30_error',1,'Error callback'],['../quick_guide.html#quick_capture_error',1,'Setting an error callback']]],
  ['error_20codes_6',['Error codes',['../group__errors.html',1,'']]],
  ['error_20free_20context_20creation_7',['Error-free context creation',['../news.html#news_32_noerror',1,'']]],
  ['error_20handling_8',['Error handling',['../intro_guide.html#error_handling',1,'']]],
  ['error_20query_9',['Error query',['../news.html#geterror_33',1,'']]],
  ['error_20reference_10',['Initialization, version and error reference',['../group__init.html',1,'']]],
  ['es_20extensions_11',['OpenGL and OpenGL ES extensions',['../context_guide.html#context_glext',1,'']]],
  ['es_20support_12',['OpenGL ES support',['../news.html#news_30_gles',1,'']]],
  ['event_13',['Path drop event',['../news.html#news_31_drop',1,'']]],
  ['event_20interface_14',['Event interface',['../internals_guide.html#internals_event',1,'']]],
  ['event_20order_15',['Event order',['../intro_guide.html#event_order',1,'']]],
  ['event_20polling_16',['Removal of automatic event polling',['../moving_guide.html#moving_autopoll',1,'']]],
  ['event_20processing_17',['event processing',['../input_guide.html#events',1,'Event processing'],['../window_guide.html#window_events',1,'Window event processing']]],
  ['events_18',['events',['../input_guide.html#cursor_enter',1,'Cursor enter/leave events'],['../news.html#wait_events_33',1,'No window required to wait for events'],['../quick_guide.html#quick_process_events',1,'Processing events'],['../quick_guide.html#quick_key_input',1,'Receiving input events'],['../window_guide.html#window_properties',1,'Window properties and events']]],
  ['events_20on_20x11_20no_20longer_20roundtrip_20to_20server_19',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['events_20with_20timeout_20',['Wait for events with timeout',['../news.html#news_32_waittimeout',1,'']]],
  ['experimental_20egl_20support_21',['(Experimental) EGL support',['../news.html#news_30_egl',1,'']]],
  ['experimental_20mir_20support_22',['(Experimental) Mir support',['../news.html#news_31_mir',1,'']]],
  ['experimental_20wayland_20support_23',['(Experimental) Wayland support',['../news.html#news_31_wayland',1,'']]],
  ['explicit_20context_20management_24',['Explicit context management',['../moving_guide.html#moving_context',1,'']]],
  ['explicit_20monitor_20selection_25',['Explicit monitor selection',['../moving_guide.html#moving_monitor',1,'']]],
  ['extension_20header_26',['Macro for including extension header',['../news.html#news_31_glext',1,'']]],
  ['extension_20libraries_20are_20loaded_20dynamically_27',['X11 extension libraries are loaded dynamically',['../news.html#x11_linking_33',1,'']]],
  ['extension_20with_20a_20loader_20library_28',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['extensions_29',['extensions',['../context_guide.html#context_glext_string',1,'Checking for extensions'],['../compat_guide.html#compat_glx',1,'GLX extensions'],['../context_guide.html#context_glext',1,'OpenGL and OpenGL ES extensions'],['../vulkan_guide.html#vulkan_ext',1,'Querying required Vulkan extensions'],['../news.html#glext_33',1,'Support for more context creation extensions'],['../compat_guide.html#compat_wsi',1,'Vulkan WSI extensions'],['../compat_guide.html#compat_wgl',1,'WGL extensions']]],
  ['extensions_20manually_30',['Loading extensions manually',['../context_guide.html#context_glext_manual',1,'']]],
  ['extensions_20protocols_20and_20ipc_20standards_31',['X11 extensions, protocols and IPC standards',['../compat_guide.html#compat_x11',1,'']]]
];

==> glfw-doc-3.3.10-1-aarch64.pkg.tar.xz: usr/share/doc/glfw/html/search/all_8.js <==
var searchData=
[
  ['egl_20support_0',['(Experimental) EGL support',['../news.html#news_30_egl',1,'']]],
  ['empty_20events_20on_20x11_20no_20longer_20roundtrip_20to_20server_1',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['enter_20leave_20callback_2',['Cursor enter/leave callback',['../news.html#news_30_enterleave',1,'']]],
  ['enter_20leave_20events_3',['Cursor enter/leave events',['../input_guide.html#cursor_enter',1,'']]],
  ['enumeration_4',['Video mode enumeration',['../moving_guide.html#moving_video_modes',1,'']]],
  ['error_20callback_5',['Error callback',['../news.html#news_30_error',1,'Error callback'],['../quick_guide.html#quick_capture_error',1,'Setting an error callback']]],
  ['error_20codes_6',['Error codes',['../group__errors.html',1,'']]],
  ['error_20free_20context_20creation_7',['Error-free context creation',['../news.html#news_32_noerror',1,'']]],
  ['error_20handling_8',['Error handling',['../intro_guide.html#error_handling',1,'']]],
  ['error_20query_9',['Error query',['../news.html#geterror_33',1,'']]],
  ['error_20reference_10',['Initialization, version and error reference',['../group__init.html',1,'']]],
  ['es_20extensions_11',['OpenGL and OpenGL ES extensions',['../context_guide.html#context_glext',1,'']]],
  ['es_20support_12',['OpenGL ES support',['../news.html#news_30_gles',1,'']]],
  ['event_13',['Path drop event',['../news.html#news_31_drop',1,'']]],
  ['event_20interface_14',['Event interface',['../internals_guide.html#internals_event',1,'']]],
  ['event_20order_15',['Event order',['../intro_guide.html#event_order',1,'']]],
  ['event_20polling_16',['Removal of automatic event polling',['../moving_guide.html#moving_autopoll',1,'']]],
  ['event_20processing_17',['Event processing',['../input_guide.html#events',1,'Event processing'],['../window_guide.html#window_events',1,'Window event processing']]],
  ['events_18',['Events',['../input_guide.html#cursor_enter',1,'Cursor enter/leave events'],['../news.html#wait_events_33',1,'No window required to wait for events'],['../quick_guide.html#quick_process_events',1,'Processing events'],['../quick_guide.html#quick_key_input',1,'Receiving input events'],['../window_guide.html#window_properties',1,'Window properties and events']]],
  ['events_20on_20x11_20no_20longer_20roundtrip_20to_20server_19',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['events_20with_20timeout_20',['Wait for events with timeout',['../news.html#news_32_waittimeout',1,'']]],
  ['experimental_20egl_20support_21',['(Experimental) EGL support',['../news.html#news_30_egl',1,'']]],
  ['experimental_20mir_20support_22',['(Experimental) Mir support',['../news.html#news_31_mir',1,'']]],
  ['experimental_20wayland_20support_23',['(Experimental) Wayland support',['../news.html#news_31_wayland',1,'']]],
  ['explicit_20context_20management_24',['Explicit context management',['../moving_guide.html#moving_context',1,'']]],
  ['explicit_20monitor_20selection_25',['Explicit monitor selection',['../moving_guide.html#moving_monitor',1,'']]],
  ['extension_20header_26',['Macro for including extension header',['../news.html#news_31_glext',1,'']]],
  ['extension_20libraries_20are_20loaded_20dynamically_27',['X11 extension libraries are loaded dynamically',['../news.html#x11_linking_33',1,'']]],
  ['extension_20with_20a_20loader_20library_28',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['extensions_29',['Extensions',['../context_guide.html#context_glext_string',1,'Checking for extensions'],['../compat_guide.html#compat_glx',1,'GLX extensions'],['../context_guide.html#context_glext',1,'OpenGL and OpenGL ES extensions'],['../vulkan_guide.html#vulkan_ext',1,'Querying required Vulkan extensions'],['../news.html#glext_33',1,'Support for more context creation extensions'],['../compat_guide.html#compat_wsi',1,'Vulkan WSI extensions'],['../compat_guide.html#compat_wgl',1,'WGL extensions']]],
  ['extensions_20manually_30',['Loading extensions manually',['../context_guide.html#context_glext_manual',1,'']]],
  ['extensions_20protocols_20and_20ipc_20standards_31',['X11 extensions, protocols and IPC standards',['../compat_guide.html#compat_x11',1,'']]]
];
